@@ -1,5 +1,5 @@
 .onLoad = function(libname, pkgname) {
-    library.dynam("sysfonts", pkgname, libname)
+    # library.dynam("sysfonts", pkgname, libname)
     add_default_font_paths()
     add_default_fonts()
 }
@@ -8,4 +8,3 @@
     clean_fonts()
     library.dynam.unload("sysfonts", libpath)
 }
-
